==> keep-trinity-3.5.13.2.tar.xz: keep-trinity-3.5.13.2/keep/app/backupconfigdialog.cpp <==
/* This file is part of the Keep project
   Copyright (C) 2005 Jean-Rémy Falleri <jr.falleri@laposte.net>

   Keep is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   Keep is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with Keep; if not, write to the
   Free Software Foundation, Inc.,
   51 Franklin Steet, Fifth Floor, Boston, MA 02110-1301, USA.           */

#include "backupconfigdialog.h"

#include <klocale.h>
#include <tqlayout.h>
#include <kurl.h>
#include <dcopref.h>
#include <kdebug.h>
#include <kactivelabel.h>
#include <kmimetype.h>
#include <tqpixmap.h>
#include <kcombobox.h>
#include <klineedit.h>
#include <kprogress.h>
#include <tqlabel.h>
#include <tqgroupbox.h>
#include <tqradiobutton.h>
#include <tqcheckbox.h>
#include <kmessagebox.h>
#include <kapplication.h>
#include <kiconloader.h>
#include <tqvaluelist.h>

#include "backupconfig.h"

BackupConfigDialog::BackupConfigDialog(TQWidget *parent):KDialogBase(Plain, i18n("Configure backups"),
	Help|Cancel|Ok, Cancel, parent, "configBackups", true, false)
{
	KIconLoader *icons = KGlobal::iconLoader();


	TQFrame *page = plainPage();
	TQVBoxLayout *topLayout = new TQVBoxLayout( page, 0, KDialog::spacingHint() );
	m_backupListWidget = new BackupListWidget(page,"backupListWidget");
	topLayout->addWidget( m_backupListWidget );
	setMainWidget(page);

	connect( this, TQT_SIGNAL( okClicked()),this, TQT_SLOT(saveSettings()));
}

void BackupConfigDialog::saveSettings()
{
	m_backupListWidget->slotSaveSettings();
}

void BackupConfigDialog::readSettings()
{

}

#include "backupconfigdialog.moc"

==> keep-trinity_14.1.0.orig.tar.xz: keep-trinity-14.1.0/keep/app/backupconfigdialog.cpp <==
/* This file is part of the Keep project
   Copyright (C) 2005 Jean-Rémy Falleri <jr.falleri@laposte.net>

   Keep is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   Keep is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with Keep; if not, write to the
   Free Software Foundation, Inc.,
   51 Franklin Steet, Fifth Floor, Boston, MA 02110-1301, USA.           */

#include "backupconfigdialog.h"

#include <tdelocale.h>
#include <tqlayout.h>
#include <kurl.h>
#include <dcopref.h>
#include <kdebug.h>
#include <kactivelabel.h>
#include <kmimetype.h>
#include <tqpixmap.h>
#include <kcombobox.h>
#include <klineedit.h>
#include <kprogress.h>
#include <tqlabel.h>
#include <tqgroupbox.h>
#include <tqradiobutton.h>
#include <tqcheckbox.h>
#include <tdemessagebox.h>
#include <tdeapplication.h>
#include <kiconloader.h>
#include <tqvaluelist.h>

#include "backupconfig.h"

BackupConfigDialog::BackupConfigDialog(TQWidget *parent):KDialogBase(Plain, i18n("Configure backups"),
	Help|Cancel|Ok, Cancel, parent, "configBackups", true, false)
{
	TDEIconLoader *icons = TDEGlobal::iconLoader();


	TQFrame *page = plainPage();
	TQVBoxLayout *topLayout = new TQVBoxLayout( page, 0, KDialog::spacingHint() );
	m_backupListWidget = new BackupListWidget(page,"backupListWidget");
	topLayout->addWidget( m_backupListWidget );
	setMainWidget(page);

	connect( this, TQT_SIGNAL( okClicked()),this, TQT_SLOT(saveSettings()));
}

void BackupConfigDialog::saveSettings()
{
	m_backupListWidget->slotSaveSettings();
}

void BackupConfigDialog::readSettings()
{

}

#include "backupconfigdialog.moc"
